import java.awt.Dimension;
import java.awt.Rectangle;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;
import java.util.ArrayList;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;
import javax.swing.BoxLayout;
import java.awt.Component;

public class ExemploJdbcJTable {
   public static void main(String[] args) throws ClassNotFoundException, SQLException {
      JFrame frame = new ExemploFrame();
   }
}

class ExemploFrame extends JFrame {

   private JPanel jPanel = null;
   private JButton jButtonClose = null;
   private JButton jButtonSearch = null;
   private JScrollPane jScrollPane = null;
   private JTable jTable = null;

   private Connection conn = null;
   private AcgDAO acgdao = null;

   public ExemploFrame() {
      super("ExemploJdbcJTable");
      this.setSize(new Dimension(495, 325));
      this.setContentPane(getJPanel());
      setVisible(true);
      initDb();
      setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
   }

   private void initDb() {
      try {
         conn = DbUtils.getConnection();
         acgdao = new AcgDAO();
         acgdao.setConnection(conn);
         acgdao.dropTable();
         acgdao.createTable();

         Acg acg1 = new Acg(1, "Participação na ERAD 2010", 30);
         Acg acg2 = new Acg(2, "Pesquisa no LSC", 60);
         Acg acg3 = new Acg(3, "Participação na ERRC 2009", 30);
         acgdao.create(acg1);
         acgdao.create(acg2);
         acgdao.create(acg3);
      } catch (Exception e) {
         e.printStackTrace();
      }
   }

   private void closeDb() {
      try {
         DbUtils.shutdown(conn);
         conn.close();
      } catch (SQLException e) {
         e.printStackTrace();
      }
   }

   private void dbToJTable() {
      try {
         ArrayList<Vector> acgs = acgdao.dumpToVector();
         DefaultTableModel model = new DefaultTableModel(acgs.get(1), Acg.attribNames());
         jTable.setModel(model);
      } catch (SQLException ex) {
         ex.printStackTrace();
      }
   }

   private JPanel getJPanel() {
      jPanel = new JPanel(); 
      jPanel.setLayout(new BoxLayout(jPanel, BoxLayout.Y_AXIS));
      jPanel.add(getJScrollPane());
      jPanel.add(getJButtonSearch());
      jPanel.add(getJButtonClose());
      return jPanel;
   }

   private JScrollPane getJScrollPane() {
      jScrollPane = new JScrollPane();
      jScrollPane.setViewportView(getJTable());
      return jScrollPane;
   }

   private JTable getJTable() {
      jTable = new JTable();
      DefaultTableModel model = new DefaultTableModel(Acg.attribNames(), 0);
      jTable.setModel(model);
      return jTable;
   }

   private JButton getJButtonSearch() {
      jButtonSearch = new JButton();
      jButtonSearch.setAlignmentX(Component.CENTER_ALIGNMENT);
      jButtonSearch.setText("Pesquisar");

      jButtonSearch.addActionListener(new java.awt.event.ActionListener() {
         public void actionPerformed(java.awt.event.ActionEvent e) {
            dbToJTable();
         }
      });
      return jButtonSearch;
   }

   private JButton getJButtonClose() {
      jButtonClose = new JButton();
      jButtonClose.setAlignmentX(Component.CENTER_ALIGNMENT);
      jButtonClose.setText("Fechar");

      jButtonClose.addActionListener(new java.awt.event.ActionListener() {
         public void actionPerformed(java.awt.event.ActionEvent e) {
            closeDb();
            System.exit(0);
         }
      });
      return jButtonClose;
   }

}

